==> istio-model-v1beta1-6.2.0-sources.jar: io/fabric8/istio/api/networking/v1beta1/DestinationRuleListFluent.java <==
package io.fabric8.istio.api.networking.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ListMeta;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import java.lang.Long;
import java.util.Iterator;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

 /**
  * Generated
  */
public interface DestinationRuleListFluent<A extends DestinationRuleListFluent<A>> extends Fluent<A>{
  public String getApiVersion();
  public A withApiVersion(String apiVersion);
  public Boolean hasApiVersion();
  public A addToItems(Integer index,DestinationRule item);
  public A setToItems(Integer index,DestinationRule item);
  public A addToItems(io.fabric8.istio.api.networking.v1beta1.DestinationRule... items);
  public A addAllToItems(Collection<DestinationRule> items);
  public A removeFromItems(io.fabric8.istio.api.networking.v1beta1.DestinationRule... items);
  public A removeAllFromItems(Collection<DestinationRule> items);
  public A removeMatchingFromItems(Predicate<DestinationRuleBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildItems instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<DestinationRule> getItems();
  public List<DestinationRule> buildItems();
  public DestinationRule buildItem(Integer index);
  public DestinationRule buildFirstItem();
  public DestinationRule buildLastItem();
  public DestinationRule buildMatchingItem(Predicate<DestinationRuleBuilder> predicate);
  public Boolean hasMatchingItem(Predicate<DestinationRuleBuilder> predicate);
  public A withItems(List<DestinationRule> items);
  public A withItems(io.fabric8.istio.api.networking.v1beta1.DestinationRule... items);
  public Boolean hasItems();
  public DestinationRuleListFluent.ItemsNested<A> addNewItem();
  public DestinationRuleListFluent.ItemsNested<A> addNewItemLike(DestinationRule item);
  public DestinationRuleListFluent.ItemsNested<A> setNewItemLike(Integer index,DestinationRule item);
  public DestinationRuleListFluent.ItemsNested<A> editItem(Integer index);
  public DestinationRuleListFluent.ItemsNested<A> editFirstItem();
  public DestinationRuleListFluent.ItemsNested<A> editLastItem();
  public DestinationRuleListFluent.ItemsNested<A> editMatchingItem(Predicate<DestinationRuleBuilder> predicate);
  public String getKind();
  public A withKind(String kind);
  public Boolean hasKind();
  public ListMeta getMetadata();
  public A withMetadata(ListMeta metadata);
  public Boolean hasMetadata();
  public A withNewMetadata(String _continue,Long remainingItemCount,String resourceVersion,String selfLink);
  public interface ItemsNested<N> extends Nested<N>,DestinationRuleFluent<DestinationRuleListFluent.ItemsNested<N>>{
    public N and();
    public N endItem();
    
  }
  
}

==> istio-model-v1beta1-6.7.2-sources.jar: io/fabric8/istio/api/networking/v1beta1/DestinationRuleListFluent.java <==
package io.fabric8.istio.api.networking.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ListMeta;
import java.util.function.Predicate;
import java.lang.Deprecated;
import java.lang.Long;
import java.util.Iterator;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

 /**
  * Generated
  */
public interface DestinationRuleListFluent<A extends DestinationRuleListFluent<A>> extends Fluent<A>{
  public String getApiVersion();
  public A withApiVersion(String apiVersion);
  public Boolean hasApiVersion();
  public A addToItems(int index,DestinationRule item);
  public A setToItems(int index,DestinationRule item);
  public A addToItems(io.fabric8.istio.api.networking.v1beta1.DestinationRule... items);
  public A addAllToItems(Collection<DestinationRule> items);
  public A removeFromItems(io.fabric8.istio.api.networking.v1beta1.DestinationRule... items);
  public A removeAllFromItems(Collection<DestinationRule> items);
  public A removeMatchingFromItems(Predicate<DestinationRuleBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildItems instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<DestinationRule> getItems();
  public List<DestinationRule> buildItems();
  public DestinationRule buildItem(int index);
  public DestinationRule buildFirstItem();
  public DestinationRule buildLastItem();
  public DestinationRule buildMatchingItem(Predicate<DestinationRuleBuilder> predicate);
  public Boolean hasMatchingItem(Predicate<DestinationRuleBuilder> predicate);
  public A withItems(List<DestinationRule> items);
  public A withItems(io.fabric8.istio.api.networking.v1beta1.DestinationRule... items);
  public Boolean hasItems();
  public DestinationRuleListFluent.ItemsNested<A> addNewItem();
  public DestinationRuleListFluent.ItemsNested<A> addNewItemLike(DestinationRule item);
  public DestinationRuleListFluent.ItemsNested<A> setNewItemLike(int index,DestinationRule item);
  public DestinationRuleListFluent.ItemsNested<A> editItem(int index);
  public DestinationRuleListFluent.ItemsNested<A> editFirstItem();
  public DestinationRuleListFluent.ItemsNested<A> editLastItem();
  public DestinationRuleListFluent.ItemsNested<A> editMatchingItem(Predicate<DestinationRuleBuilder> predicate);
  public String getKind();
  public A withKind(String kind);
  public Boolean hasKind();
  public ListMeta getMetadata();
  public A withMetadata(ListMeta metadata);
  public Boolean hasMetadata();
  public A withNewMetadata(String _continue,Long remainingItemCount,String resourceVersion,String selfLink);
  public interface ItemsNested<N> extends Nested<N>,DestinationRuleFluent<DestinationRuleListFluent.ItemsNested<N>>{
    public N and();
    public N endItem();
    
  }
  
}
